import { Controller, Get, Param } from "@nestjs/common";
import { Query, UseGuards } from "@nestjs/common/decorators";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { SiteFrontendService } from "./site-frontend.service";

@Controller({
    path: "site",
    version: Constants.API_VERSION_1
})
export class SiteFrontendController {
    constructor(private readonly service: SiteFrontendService) {}

    @Get("/about")
    getAboutPageData() {
        return this.service.getAboutPageData();
    }

    @Get("/contact")
    getContactPageData() {
        return this.service.getContactPageData();
    }

    @Get("/faq")
    getFaqPageData() {
        return this.service.getFaqPageData();
    }

    @Get("/quiz")
    getQuizPageData() {
        return this.service.getQuizPageData();
    }

    @Get("/footer")
    getFooterData() {
        return this.service.getFooterData();
    }

    @Get("/career")
    getCareerPageData() {
        return this.service.getCareerPageData();
    }

    @Get("/career-list")
    getCareerDepartmentWiseData(
      @Query("departmentName") departmentName: any
    ) {
        return this.service.getCareerDepartmentWiseData(departmentName);
    }

    @Get("/career/:id")
    getCareerDetailsData(@Param("id") id: string) {
        return this.service.getCareerDetailsData(id);
    }

    @Get("/home")
    getHomePageData() {
        return this.service.getHomePageData();
    }

    @Get("/press-release")
    getPressReleaseData() {
        return this.service.getPressReleaseData();
    }

    @Get("/press-release/:urlSlug")
    getPressReleaseDetailsData(@Param("urlSlug") urlSlug: string) {
        return this.service.getPressReleaseDetailsData(urlSlug);
    }

    @Get("/article")
    getArticleData(
      @Query("page") page: number,
      @Query("limit") limit: number,
      @Query("keyword") keyword?: any,
      @Query("tagName") tagName?: any,
      @Query("categoryId") categoryId?: any
    ) {
        return this.service.getArticleData(page, limit, keyword, tagName, categoryId);
    }

    @Get("/article-details/:urlSlug")
    getArticleDetailsData(@Param("urlSlug") urlSlug: string) {
        return this.service.getArticleDetailsData(urlSlug);
    }

    @Get("/discover-menu-hover")
    getDiscoverHoverMenuData() {
        return this.service.getDiscoverHoverMenuData();
    }

    @Get("/admin-dashboard")
    @UseGuards(AdminAuthGuard)
    getDashboardData() {
        return this.service.getDashboardData();
    }
}
